import * as Models from './models';
import * as Parameters from './parameters';
import { Callback } from '../callback';
import { Client } from '../clients';
export declare class Template {
    private client;
    constructor(client: Client);
    /**
     * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to create a
     * space template or 'Confluence Administrator' global permission to create a global template.
     */
    createContentTemplate<T = Models.ContentTemplate>(parameters: Parameters.CreateContentTemplate | undefined, callback: Callback<T>): Promise<void>;
    /**
     * Creates a new content template. Note, blueprint templates cannot be created via the REST API.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to create a
     * space template or 'Confluence Administrator' global permission to create a global template.
     */
    createContentTemplate<T = Models.ContentTemplate>(parameters?: Parameters.CreateContentTemplate, callback?: never): Promise<T>;
    /**
     * Updates a content template. Note, blueprint templates cannot be updated via the REST API.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to update a
     * space template or 'Confluence Administrator' global permission to update a global template.
     */
    updateContentTemplate<T = Models.ContentTemplate>(parameters: Parameters.UpdateContentTemplate | undefined, callback: Callback<T>): Promise<void>;
    /**
     * Updates a content template. Note, blueprint templates cannot be updated via the REST API.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to update a
     * space template or 'Confluence Administrator' global permission to update a global template.
     */
    updateContentTemplate<T = Models.ContentTemplate>(parameters?: Parameters.UpdateContentTemplate, callback?: never): Promise<T>;
    /**
     * Returns all templates provided by blueprints. Use this method to retrieve all global blueprint templates or all
     * blueprint templates in a space.
     *
     * Note, all global blueprints are inherited by each space. Space blueprints can be customised without affecting the
     * global blueprints.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * blueprints for the space and permission to access the Confluence site ('Can use' global permission) to view global
     * blueprints.
     */
    getBlueprintTemplates<T = Models.BlueprintTemplateArray>(parameters: Parameters.GetBlueprintTemplates | undefined, callback: Callback<T>): Promise<void>;
    /**
     * Returns all templates provided by blueprints. Use this method to retrieve all global blueprint templates or all
     * blueprint templates in a space.
     *
     * Note, all global blueprints are inherited by each space. Space blueprints can be customised without affecting the
     * global blueprints.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * blueprints for the space and permission to access the Confluence site ('Can use' global permission) to view global
     * blueprints.
     */
    getBlueprintTemplates<T = Models.BlueprintTemplateArray>(parameters?: Parameters.GetBlueprintTemplates, callback?: never): Promise<T>;
    /**
     * Returns all content templates. Use this method to retrieve all global content templates or all content templates in
     * a space.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * space templates and permission to access the Confluence site ('Can use' global permission) to view global
     * templates.
     */
    getContentTemplates<T = Models.ContentTemplateArray>(parameters: Parameters.GetContentTemplates | undefined, callback: Callback<T>): Promise<void>;
    /**
     * Returns all content templates. Use this method to retrieve all global content templates or all content templates in
     * a space.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * space templates and permission to access the Confluence site ('Can use' global permission) to view global
     * templates.
     */
    getContentTemplates<T = Models.ContentTemplateArray>(parameters?: Parameters.GetContentTemplates, callback?: never): Promise<T>;
    /**
     * Returns a content template. This includes information about template, like the name, the space or blueprint that
     * the template is in, the body of the template, and more.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * space templates and permission to access the Confluence site ('Can use' global permission) to view global
     * templates.
     */
    getContentTemplate<T = Models.ContentTemplate>(parameters: Parameters.GetContentTemplate, callback: Callback<T>): Promise<void>;
    /**
     * Returns a content template. This includes information about template, like the name, the space or blueprint that
     * the template is in, the body of the template, and more.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'View' permission for the space to view
     * space templates and permission to access the Confluence site ('Can use' global permission) to view global
     * templates.
     */
    getContentTemplate<T = Models.ContentTemplate>(parameters: Parameters.GetContentTemplate, callback?: never): Promise<T>;
    /**
     * Deletes a template. This results in different actions depending on the type of template:
     *
     * - If the template is a content template, it is deleted.
     * - If the template is a modified space-level blueprint template, it reverts to the template inherited from the
     *   global-level blueprint template.
     * - If the template is a modified global-level blueprint template, it reverts to the default global-level blueprint
     *   template.
     *
     * Note, unmodified blueprint templates cannot be deleted.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to delete a
     * space template or 'Confluence Administrator' global permission to delete a global template.
     */
    removeTemplate<T = void>(parameters: Parameters.RemoveTemplate, callback: Callback<T>): Promise<void>;
    /**
     * Deletes a template. This results in different actions depending on the type of template:
     *
     * - If the template is a content template, it is deleted.
     * - If the template is a modified space-level blueprint template, it reverts to the template inherited from the
     *   global-level blueprint template.
     * - If the template is a modified global-level blueprint template, it reverts to the default global-level blueprint
     *   template.
     *
     * Note, unmodified blueprint templates cannot be deleted.
     *
     * **[Permissions](https://confluence.atlassian.com/x/_AozKw) required**: 'Admin' permission for the space to delete a
     * space template or 'Confluence Administrator' global permission to delete a global template.
     */
    removeTemplate<T = void>(parameters: Parameters.RemoveTemplate, callback?: never): Promise<T>;
}
